@@ -1,4 +1,4 @@
 from test.bases import WorldTestBase
 
 class DredgeTestBase(WorldTestBase):
-    game = "Dredge"
\ No newline at end of file
+    game = "DREDGE"
\ No newline at end of file
